/*****************************************************************************
* SASload_KID_2012_Core.SAS
* This program will load the 2012 KID ASCII Core File into SAS.
*****************************************************************************/

*** Create SAS informats for missing values ***;
PROC FORMAT;
  INVALUE N2PF
    '-9' = .
    '-8' = .A
    '-6' = .C
    '-5' = .N
    OTHER = (|2.|)
  ;
  INVALUE N3PF
    '-99' = .
    '-88' = .A
    '-66' = .C
    OTHER = (|3.|)
  ;
  INVALUE N4PF
    '-999' = .
    '-888' = .A
    '-666' = .C
    OTHER = (|4.|)
  ;
  INVALUE N4P1F
    '-9.9' = .
    '-8.8' = .A
    '-6.6' = .C
    OTHER = (|4.1|)
  ;
  INVALUE N5PF
    '-9999' = .
    '-8888' = .A
    '-6666' = .C
    OTHER = (|5.|)
  ;
  INVALUE N5P2F
    '-9.99' = .
    '-8.88' = .A
    '-6.66' = .C
    OTHER = (|5.2|)
  ;
  INVALUE N6PF
    '-99999' = .
    '-88888' = .A
    '-66666' = .C
    OTHER = (|6.|)
  ;
  INVALUE N6P2F
    '-99.99' = .
    '-88.88' = .A
    '-66.66' = .C
    OTHER = (|6.2|)
  ;
  INVALUE N7P2F
    '-999.99' = .
    '-888.88' = .A
    '-666.66' = .C
    OTHER = (|7.2|)
  ;
  INVALUE N8PF
    '-9999999' = .
    '-8888888' = .A
    '-6666666' = .C
    OTHER = (|8.|)
  ;
  INVALUE N8P2F
    '-9999.99' = .
    '-8888.88' = .A
    '-6666.66' = .C
    OTHER = (|8.2|)
  ;
  INVALUE N8P4F
    '-99.9999' = .
    '-88.8888' = .A
    '-66.6666' = .C
    OTHER = (|8.4|)
  ;
  INVALUE N10PF
    '-999999999' = .
    '-888888888' = .A
    '-666666666' = .C
    OTHER = (|10.|)
  ;
  INVALUE N10P4F
    '-9999.9999' = .
    '-8888.8888' = .A
    '-6666.6666' = .C
    OTHER = (|10.4|)
  ;
  INVALUE N10P5F
    '-999.99999' = .
    '-888.88888' = .A
    '-666.66666' = .C
    OTHER = (|10.5|)
  ;
  INVALUE DATE10F
    '-999999999' = .
    '-888888888' = .A
    '-666666666' = .C
    OTHER = (|MMDDYY10.|)
  ;
  INVALUE N11P7F
    '-99.9999999' = .
    '-88.8888888' = .A
    '-66.6666666' = .C
    OTHER = (|11.7|)
  ;
  INVALUE N12P2F
    '-99999999.99' = .
    '-88888888.88' = .A
    '-66666666.66' = .C
    OTHER = (|12.2|)
  ;
  INVALUE N12P5F
    '-99999.99999' = .
    '-88888.88888' = .A
    '-66666.66666' = .C
    OTHER = (|12.5|)
  ;
  INVALUE N13PF
    '-999999999999' = .
    '-888888888888' = .A
    '-666666666666' = .C
    OTHER = (|13.|)
  ;
  INVALUE N15P2F
    '-99999999999.99' = .
    '-88888888888.88' = .A
    '-66666666666.66' = .C
    OTHER = (|15.2|)
  ;
RUN;

*** Data Step to load the file ***;
DATA KID_2012_Core; 
INFILE 'KID_2012_Core.ASC' LRECL = 504;

*** Define data element attributes ***;
ATTRIB 
  HOSP_KID                   LENGTH=4            FORMAT=Z5.
  LABEL="KID hospital number"

  RECNUM                     LENGTH=5            FORMAT=Z8.
  LABEL="KID record number"

  AGE                        LENGTH=3
  LABEL="Age in years at admission"

  AGE_NEONATE                LENGTH=3
  LABEL="Neonatal age (first 28 days after birth) indicator"

  AMONTH                     LENGTH=3
  LABEL="Admission month"

  AWEEKEND                   LENGTH=3
  LABEL="Admission day is a weekend"

  DIED                       LENGTH=3
  LABEL="Died during hospitalization"

  DISCWT                     LENGTH=8
  LABEL="KID discharge weight"

  DISPUNIFORM                LENGTH=3
  LABEL="Disposition of patient (uniform)"

  DQTR                       LENGTH=3
  LABEL="Discharge quarter"

  DRG                        LENGTH=3
  LABEL="DRG in effect on discharge date"

  DRG24                      LENGTH=3
  LABEL="DRG, version 24"

  DRGVER                     LENGTH=3
  LABEL="DRG grouper version used on discharge date"

  DRG_NoPOA                  LENGTH=3
  LABEL="DRG in use on discharge date, calculated without POA"

  DX1                        LENGTH=$5
  LABEL="Diagnosis 1"

  DX2                        LENGTH=$5
  LABEL="Diagnosis 2"

  DX3                        LENGTH=$5
  LABEL="Diagnosis 3"

  DX4                        LENGTH=$5
  LABEL="Diagnosis 4"

  DX5                        LENGTH=$5
  LABEL="Diagnosis 5"

  DX6                        LENGTH=$5
  LABEL="Diagnosis 6"

  DX7                        LENGTH=$5
  LABEL="Diagnosis 7"

  DX8                        LENGTH=$5
  LABEL="Diagnosis 8"

  DX9                        LENGTH=$5
  LABEL="Diagnosis 9"

  DX10                       LENGTH=$5
  LABEL="Diagnosis 10"

  DX11                       LENGTH=$5
  LABEL="Diagnosis 11"

  DX12                       LENGTH=$5
  LABEL="Diagnosis 12"

  DX13                       LENGTH=$5
  LABEL="Diagnosis 13"

  DX14                       LENGTH=$5
  LABEL="Diagnosis 14"

  DX15                       LENGTH=$5
  LABEL="Diagnosis 15"

  DX16                       LENGTH=$5
  LABEL="Diagnosis 16"

  DX17                       LENGTH=$5
  LABEL="Diagnosis 17"

  DX18                       LENGTH=$5
  LABEL="Diagnosis 18"

  DX19                       LENGTH=$5
  LABEL="Diagnosis 19"

  DX20                       LENGTH=$5
  LABEL="Diagnosis 20"

  DX21                       LENGTH=$5
  LABEL="Diagnosis 21"

  DX22                       LENGTH=$5
  LABEL="Diagnosis 22"

  DX23                       LENGTH=$5
  LABEL="Diagnosis 23"

  DX24                       LENGTH=$5
  LABEL="Diagnosis 24"

  DX25                       LENGTH=$5
  LABEL="Diagnosis 25"

  DXCCS1                     LENGTH=4
  LABEL="CCS: diagnosis 1"

  DXCCS2                     LENGTH=4
  LABEL="CCS: diagnosis 2"

  DXCCS3                     LENGTH=4
  LABEL="CCS: diagnosis 3"

  DXCCS4                     LENGTH=4
  LABEL="CCS: diagnosis 4"

  DXCCS5                     LENGTH=4
  LABEL="CCS: diagnosis 5"

  DXCCS6                     LENGTH=4
  LABEL="CCS: diagnosis 6"

  DXCCS7                     LENGTH=4
  LABEL="CCS: diagnosis 7"

  DXCCS8                     LENGTH=4
  LABEL="CCS: diagnosis 8"

  DXCCS9                     LENGTH=4
  LABEL="CCS: diagnosis 9"

  DXCCS10                    LENGTH=4
  LABEL="CCS: diagnosis 10"

  DXCCS11                    LENGTH=4
  LABEL="CCS: diagnosis 11"

  DXCCS12                    LENGTH=4
  LABEL="CCS: diagnosis 12"

  DXCCS13                    LENGTH=4
  LABEL="CCS: diagnosis 13"

  DXCCS14                    LENGTH=4
  LABEL="CCS: diagnosis 14"

  DXCCS15                    LENGTH=4
  LABEL="CCS: diagnosis 15"

  DXCCS16                    LENGTH=4
  LABEL="CCS: diagnosis 16"

  DXCCS17                    LENGTH=4
  LABEL="CCS: diagnosis 17"

  DXCCS18                    LENGTH=4
  LABEL="CCS: diagnosis 18"

  DXCCS19                    LENGTH=4
  LABEL="CCS: diagnosis 19"

  DXCCS20                    LENGTH=4
  LABEL="CCS: diagnosis 20"

  DXCCS21                    LENGTH=4
  LABEL="CCS: diagnosis 21"

  DXCCS22                    LENGTH=4
  LABEL="CCS: diagnosis 22"

  DXCCS23                    LENGTH=4
  LABEL="CCS: diagnosis 23"

  DXCCS24                    LENGTH=4
  LABEL="CCS: diagnosis 24"

  DXCCS25                    LENGTH=4
  LABEL="CCS: diagnosis 25"

  ECODE1                     LENGTH=$5
  LABEL="E code 1"

  ECODE2                     LENGTH=$5
  LABEL="E code 2"

  ECODE3                     LENGTH=$5
  LABEL="E code 3"

  ECODE4                     LENGTH=$5
  LABEL="E code 4"

  ELECTIVE                   LENGTH=3
  LABEL="Elective versus non-elective admission"

  E_CCS1                     LENGTH=3
  LABEL="CCS: E Code 1"

  E_CCS2                     LENGTH=3
  LABEL="CCS: E Code 2"

  E_CCS3                     LENGTH=3
  LABEL="CCS: E Code 3"

  E_CCS4                     LENGTH=3
  LABEL="CCS: E Code 4"

  FEMALE                     LENGTH=3
  LABEL="Indicator of sex"

  HCUP_ED                    LENGTH=3
  LABEL="HCUP Emergency Department service indicator"

  HOSPBRTH                   LENGTH=3
  LABEL="Indicator of birth in this hospital"

  HOSP_REGION                LENGTH=3            FORMAT=2.
  LABEL="Region of hospital"

  KID_STRATUM                LENGTH=4
  LABEL="Stratum used to sample hospital"

  LOS                        LENGTH=4
  LABEL="Length of stay (cleaned)"

  MDC                        LENGTH=3
  LABEL="MDC in effect on discharge date"

  MDC24                      LENGTH=3
  LABEL="MDC, version 24"

  MDC_NoPOA                  LENGTH=3
  LABEL="MDC in use on discharge date, calculated without POA"

  NCHRONIC                   LENGTH=3
  LABEL="Number of chronic conditions"

  NDX                        LENGTH=3
  LABEL="Number of diagnoses on this record"

  NECODE                     LENGTH=3
  LABEL="Number of E codes on this record"

  NEOMAT                     LENGTH=3
  LABEL="Neonatal and/or maternal DX and/or PR"

  NPR                        LENGTH=3
  LABEL="Number of procedures on this record"

  ORPROC                     LENGTH=3
  LABEL="Major operating room procedure indicator"

  PAY1                       LENGTH=3
  LABEL="Primary expected payer (uniform)"

  PL_NCHS2006                LENGTH=3
  LABEL="Patient Location: NCHS Urban-Rural Code (V2006)"

  PR1                        LENGTH=$4
  LABEL="Procedure 1"

  PR2                        LENGTH=$4
  LABEL="Procedure 2"

  PR3                        LENGTH=$4
  LABEL="Procedure 3"

  PR4                        LENGTH=$4
  LABEL="Procedure 4"

  PR5                        LENGTH=$4
  LABEL="Procedure 5"

  PR6                        LENGTH=$4
  LABEL="Procedure 6"

  PR7                        LENGTH=$4
  LABEL="Procedure 7"

  PR8                        LENGTH=$4
  LABEL="Procedure 8"

  PR9                        LENGTH=$4
  LABEL="Procedure 9"

  PR10                       LENGTH=$4
  LABEL="Procedure 10"

  PR11                       LENGTH=$4
  LABEL="Procedure 11"

  PR12                       LENGTH=$4
  LABEL="Procedure 12"

  PR13                       LENGTH=$4
  LABEL="Procedure 13"

  PR14                       LENGTH=$4
  LABEL="Procedure 14"

  PR15                       LENGTH=$4
  LABEL="Procedure 15"

  PRCCS1                     LENGTH=3
  LABEL="CCS: procedure 1"

  PRCCS2                     LENGTH=3
  LABEL="CCS: procedure 2"

  PRCCS3                     LENGTH=3
  LABEL="CCS: procedure 3"

  PRCCS4                     LENGTH=3
  LABEL="CCS: procedure 4"

  PRCCS5                     LENGTH=3
  LABEL="CCS: procedure 5"

  PRCCS6                     LENGTH=3
  LABEL="CCS: procedure 6"

  PRCCS7                     LENGTH=3
  LABEL="CCS: procedure 7"

  PRCCS8                     LENGTH=3
  LABEL="CCS: procedure 8"

  PRCCS9                     LENGTH=3
  LABEL="CCS: procedure 9"

  PRCCS10                    LENGTH=3
  LABEL="CCS: procedure 10"

  PRCCS11                    LENGTH=3
  LABEL="CCS: procedure 11"

  PRCCS12                    LENGTH=3
  LABEL="CCS: procedure 12"

  PRCCS13                    LENGTH=3
  LABEL="CCS: procedure 13"

  PRCCS14                    LENGTH=3
  LABEL="CCS: procedure 14"

  PRCCS15                    LENGTH=3
  LABEL="CCS: procedure 15"

  PRDAY1                     LENGTH=4
  LABEL="Number of days from admission to PR1"

  PRDAY2                     LENGTH=4
  LABEL="Number of days from admission to PR2"

  PRDAY3                     LENGTH=4
  LABEL="Number of days from admission to PR3"

  PRDAY4                     LENGTH=4
  LABEL="Number of days from admission to PR4"

  PRDAY5                     LENGTH=4
  LABEL="Number of days from admission to PR5"

  PRDAY6                     LENGTH=4
  LABEL="Number of days from admission to PR6"

  PRDAY7                     LENGTH=4
  LABEL="Number of days from admission to PR7"

  PRDAY8                     LENGTH=4
  LABEL="Number of days from admission to PR8"

  PRDAY9                     LENGTH=4
  LABEL="Number of days from admission to PR9"

  PRDAY10                    LENGTH=4
  LABEL="Number of days from admission to PR10"

  PRDAY11                    LENGTH=4
  LABEL="Number of days from admission to PR11"

  PRDAY12                    LENGTH=4
  LABEL="Number of days from admission to PR12"

  PRDAY13                    LENGTH=4
  LABEL="Number of days from admission to PR13"

  PRDAY14                    LENGTH=4
  LABEL="Number of days from admission to PR14"

  PRDAY15                    LENGTH=4
  LABEL="Number of days from admission to PR15"

  RACE                       LENGTH=3
  LABEL="Race (uniform)"

  TOTCHG                     LENGTH=6
  LABEL="Total charges (cleaned)"

  TRAN_IN                    LENGTH=3
  LABEL="Transfer in indicator"

  TRAN_OUT                   LENGTH=3
  LABEL="Transfer out indicator"

  UNCBRTH                    LENGTH=3
  LABEL="Normal uncomplicated birth in hospital"

  YEAR                       LENGTH=3
  LABEL="Calendar year"

  ZIPINC_QRTL                LENGTH=3
  LABEL="Median household income national quartile for patient ZIP Code"
  ;

*** Read data elements from the ASCII file ***;
INPUT 
      @1      HOSP_KID                 N5PF.
      @6      RECNUM                   N8PF.
      @14     AGE                      N3PF.
      @17     AGE_NEONATE              N2PF.
      @19     AMONTH                   N2PF.
      @21     AWEEKEND                 N2PF.
      @23     DIED                     N2PF.
      @25     DISCWT                   N11P7F.
      @36     DISPUNIFORM              N2PF.
      @38     DQTR                     N2PF.
      @40     DRG                      N3PF.
      @43     DRG24                    N3PF.
      @46     DRGVER                   N2PF.
      @48     DRG_NoPOA                N3PF.
      @51     DX1                      $CHAR5.
      @56     DX2                      $CHAR5.
      @61     DX3                      $CHAR5.
      @66     DX4                      $CHAR5.
      @71     DX5                      $CHAR5.
      @76     DX6                      $CHAR5.
      @81     DX7                      $CHAR5.
      @86     DX8                      $CHAR5.
      @91     DX9                      $CHAR5.
      @96     DX10                     $CHAR5.
      @101    DX11                     $CHAR5.
      @106    DX12                     $CHAR5.
      @111    DX13                     $CHAR5.
      @116    DX14                     $CHAR5.
      @121    DX15                     $CHAR5.
      @126    DX16                     $CHAR5.
      @131    DX17                     $CHAR5.
      @136    DX18                     $CHAR5.
      @141    DX19                     $CHAR5.
      @146    DX20                     $CHAR5.
      @151    DX21                     $CHAR5.
      @156    DX22                     $CHAR5.
      @161    DX23                     $CHAR5.
      @166    DX24                     $CHAR5.
      @171    DX25                     $CHAR5.
      @176    DXCCS1                   N3PF.
      @179    DXCCS2                   N3PF.
      @182    DXCCS3                   N3PF.
      @185    DXCCS4                   N3PF.
      @188    DXCCS5                   N3PF.
      @191    DXCCS6                   N3PF.
      @194    DXCCS7                   N3PF.
      @197    DXCCS8                   N3PF.
      @200    DXCCS9                   N3PF.
      @203    DXCCS10                  N3PF.
      @206    DXCCS11                  N3PF.
      @209    DXCCS12                  N3PF.
      @212    DXCCS13                  N3PF.
      @215    DXCCS14                  N3PF.
      @218    DXCCS15                  N3PF.
      @221    DXCCS16                  N3PF.
      @224    DXCCS17                  N3PF.
      @227    DXCCS18                  N3PF.
      @230    DXCCS19                  N3PF.
      @233    DXCCS20                  N3PF.
      @236    DXCCS21                  N3PF.
      @239    DXCCS22                  N3PF.
      @242    DXCCS23                  N3PF.
      @245    DXCCS24                  N3PF.
      @248    DXCCS25                  N3PF.
      @251    ECODE1                   $CHAR5.
      @256    ECODE2                   $CHAR5.
      @261    ECODE3                   $CHAR5.
      @266    ECODE4                   $CHAR5.
      @271    ELECTIVE                 N2PF.
      @273    E_CCS1                   N4PF.
      @277    E_CCS2                   N4PF.
      @281    E_CCS3                   N4PF.
      @285    E_CCS4                   N4PF.
      @289    FEMALE                   N2PF.
      @291    HCUP_ED                  N3PF.
      @294    HOSPBRTH                 N2PF.
      @296    HOSP_REGION              N2PF.
      @298    KID_STRATUM              N4PF.
      @302    LOS                      N5PF.
      @307    MDC                      N2PF.
      @309    MDC24                    N2PF.
      @311    MDC_NoPOA                N2PF.
      @313    NCHRONIC                 N2PF.
      @315    NDX                      N2PF.
      @317    NECODE                   N3PF.
      @320    NEOMAT                   N2PF.
      @322    NPR                      N2PF.
      @324    ORPROC                   N2PF.
      @326    PAY1                     N2PF.
      @328    PL_NCHS2006              N3PF.
      @331    PR1                      $CHAR4.
      @335    PR2                      $CHAR4.
      @339    PR3                      $CHAR4.
      @343    PR4                      $CHAR4.
      @347    PR5                      $CHAR4.
      @351    PR6                      $CHAR4.
      @355    PR7                      $CHAR4.
      @359    PR8                      $CHAR4.
      @363    PR9                      $CHAR4.
      @367    PR10                     $CHAR4.
      @371    PR11                     $CHAR4.
      @375    PR12                     $CHAR4.
      @379    PR13                     $CHAR4.
      @383    PR14                     $CHAR4.
      @387    PR15                     $CHAR4.
      @391    PRCCS1                   N3PF.
      @394    PRCCS2                   N3PF.
      @397    PRCCS3                   N3PF.
      @400    PRCCS4                   N3PF.
      @403    PRCCS5                   N3PF.
      @406    PRCCS6                   N3PF.
      @409    PRCCS7                   N3PF.
      @412    PRCCS8                   N3PF.
      @415    PRCCS9                   N3PF.
      @418    PRCCS10                  N3PF.
      @421    PRCCS11                  N3PF.
      @424    PRCCS12                  N3PF.
      @427    PRCCS13                  N3PF.
      @430    PRCCS14                  N3PF.
      @433    PRCCS15                  N3PF.
      @436    PRDAY1                   N3PF.
      @439    PRDAY2                   N3PF.
      @442    PRDAY3                   N3PF.
      @445    PRDAY4                   N3PF.
      @448    PRDAY5                   N3PF.
      @451    PRDAY6                   N3PF.
      @454    PRDAY7                   N3PF.
      @457    PRDAY8                   N3PF.
      @460    PRDAY9                   N3PF.
      @463    PRDAY10                  N3PF.
      @466    PRDAY11                  N3PF.
      @469    PRDAY12                  N3PF.
      @472    PRDAY13                  N3PF.
      @475    PRDAY14                  N3PF.
      @478    PRDAY15                  N3PF.
      @481    RACE                     N2PF.
      @483    TOTCHG                   N10PF.
      @493    TRAN_IN                  N2PF.
      @495    TRAN_OUT                 N2PF.
      @497    UNCBRTH                  N2PF.
      @499    YEAR                     N4PF.
      @503    ZIPINC_QRTL              N2PF.
      ;
RUN;
