/*******************************************************************
*   SASload_KID_2003_CORE.SAS:                                
*      THE SAS CODE SHOWN BELOW WILL LOAD THE ASCII                 
*      INPATIENT STAY CORE FILE INTO SAS                          
*******************************************************************/


***********************************************;
*  Create SAS informats for missing values     ;
***********************************************;
PROC FORMAT;
  INVALUE N2PF
    '-9' = .
    '-8' = .A
    '-6' = .C
    '-5' = .N
    OTHER = (|2.|)
  ;
  INVALUE N3PF
    '-99' = .
    '-88' = .A
    '-66' = .C
    OTHER = (|3.|)
  ;
  INVALUE N4PF
    '-999' = .
    '-888' = .A
    '-666' = .C
    OTHER = (|4.|)
  ;
  INVALUE N5PF
    '-9999' = .
    '-8888' = .A
    '-6666' = .C
    OTHER = (|5.|)
  ;
  INVALUE N5P2F
    '-9.99' = .
    '-8.88' = .A
    '-6.66' = .C
    OTHER = (|5.2|)
  ;
  INVALUE N6PF
    '-99999' = .
    '-88888' = .A
    '-66666' = .C
    OTHER = (|6.|)
  ;
  INVALUE N6P2F
    '-99.99' = .
    '-88.88' = .A
    '-66.66' = .C
    OTHER = (|6.2|)
  ;
  INVALUE N7P2F
    '-999.99' = .
    '-888.88' = .A
    '-666.66' = .C
    OTHER = (|7.2|)
  ;
  INVALUE N8PF
    '-9999999' = .
    '-8888888' = .A
    '-6666666' = .C
    OTHER = (|8.|)
  ;
  INVALUE N8P2F
    '-9999.99' = .
    '-8888.88' = .A
    '-6666.66' = .C
    OTHER = (|8.2|)
  ;
  INVALUE N8P4F
    '-99.9999' = .
    '-88.8888' = .A
    '-66.6666' = .C
    OTHER = (|8.4|)
  ;
  INVALUE N10PF
    '-999999999' = .
    '-888888888' = .A
    '-666666666' = .C
    OTHER = (|10.|)
  ;
  INVALUE N10P4F
    '-9999.9999' = .
    '-8888.8888' = .A
    '-6666.6666' = .C
    OTHER = (|10.4|)
  ;
  INVALUE N10P5F
    '-999.99999' = .
    '-888.88888' = .A
    '-666.66666' = .C
    OTHER = (|10.5|)
  ;
  INVALUE DATE10F
    '-999999999' = .
    '-888888888' = .A
    '-666666666' = .C
    OTHER = (|MMDDYY10.|)
  ;
  INVALUE N11P7F
    '-99.9999999' = .
    '-88.8888888' = .A
    '-66.6666666' = .C
    OTHER = (|11.7|)
  ;
  INVALUE N12P2F
    '-99999999.99' = .
    '-88888888.88' = .A
    '-66666666.66' = .C
    OTHER = (|12.2|)
  ;
  INVALUE N12P5F
    '-99999.99999' = .
    '-88888.88888' = .A
    '-66666.66666' = .C
    OTHER = (|12.5|)
  ;
  INVALUE N15P2F
    '-99999999999.99' = .
    '-88888888888.88' = .A
    '-66666666666.66' = .C
    OTHER = (|15.2|)
  ;
  RUN;


*******************************;
*  Data Step                  *;
*******************************;
DATA KID_2003_CORE; 
INFILE 'KID_2003_CORE.ASC' LRECL = 511;                                                                                                                                                                                                    

*** Variable attribute ***;
ATTRIB 
  HOSPID                     LENGTH=4            FORMAT=Z5.
  LABEL="HCUP hospital identification number"

  RECNUM                     LENGTH=5            FORMAT=Z8.
  LABEL="HCUP record number"

  AGE                        LENGTH=3
  LABEL="Age in years at admission"

  AGEDAY                     LENGTH=3
  LABEL="Age in days (when age < 1 year)"

  AGEMONTH                   LENGTH=3
  LABEL="Age in months (when age < 11 years)"

  AMONTH                     LENGTH=3
  LABEL="Admission month"

  ASOURCE                    LENGTH=3
  LABEL="Admission source (uniform)"

  ASOURCEUB92                LENGTH=$1
  LABEL="Admission source (UB-92 standard coding)"

  ASOURCE_X                  LENGTH=$8
  LABEL="Admission source (as received from source)"

  ATYPE                      LENGTH=3
  LABEL="Admission type"

  AWEEKEND                   LENGTH=3
  LABEL="Admission day is a weekend"

  BWT                        LENGTH=4
  LABEL="Birth weight in grams"

  DIED                       LENGTH=3
  LABEL="Died during hospitalization"

  DISCWT                     LENGTH=8
  LABEL="Weight to discharges in AHA universe"

  DISPUB92                   LENGTH=3
  LABEL="Disposition of patient (UB-92 standard coding)"

  DISPUNIFORM                LENGTH=3
  LABEL="Disposition of patient (uniform)"

  DQTR                       LENGTH=3
  LABEL="Discharge quarter"

  DRG                        LENGTH=3
  LABEL="DRG in effect on discharge date"

  DRG18                      LENGTH=3
  LABEL="DRG, version 18"

  DRGVER                     LENGTH=3
  LABEL="DRG grouper version used on discharge date"

  DSHOSPID                   LENGTH=$13
  LABEL="Data source hospital identifier"

  DX1                        LENGTH=$5
  LABEL="Principal diagnosis"

  DX2                        LENGTH=$5
  LABEL="Diagnosis 2"

  DX3                        LENGTH=$5
  LABEL="Diagnosis 3"

  DX4                        LENGTH=$5
  LABEL="Diagnosis 4"

  DX5                        LENGTH=$5
  LABEL="Diagnosis 5"

  DX6                        LENGTH=$5
  LABEL="Diagnosis 6"

  DX7                        LENGTH=$5
  LABEL="Diagnosis 7"

  DX8                        LENGTH=$5
  LABEL="Diagnosis 8"

  DX9                        LENGTH=$5
  LABEL="Diagnosis 9"

  DX10                       LENGTH=$5
  LABEL="Diagnosis 10"

  DX11                       LENGTH=$5
  LABEL="Diagnosis 11"

  DX12                       LENGTH=$5
  LABEL="Diagnosis 12"

  DX13                       LENGTH=$5
  LABEL="Diagnosis 13"

  DX14                       LENGTH=$5
  LABEL="Diagnosis 14"

  DX15                       LENGTH=$5
  LABEL="Diagnosis 15"

  DXCCS1                     LENGTH=4
  LABEL="CCS: principal diagnosis"

  DXCCS2                     LENGTH=4
  LABEL="CCS: diagnosis 2"

  DXCCS3                     LENGTH=4
  LABEL="CCS: diagnosis 3"

  DXCCS4                     LENGTH=4
  LABEL="CCS: diagnosis 4"

  DXCCS5                     LENGTH=4
  LABEL="CCS: diagnosis 5"

  DXCCS6                     LENGTH=4
  LABEL="CCS: diagnosis 6"

  DXCCS7                     LENGTH=4
  LABEL="CCS: diagnosis 7"

  DXCCS8                     LENGTH=4
  LABEL="CCS: diagnosis 8"

  DXCCS9                     LENGTH=4
  LABEL="CCS: diagnosis 9"

  DXCCS10                    LENGTH=4
  LABEL="CCS: diagnosis 10"

  DXCCS11                    LENGTH=4
  LABEL="CCS: diagnosis 11"

  DXCCS12                    LENGTH=4
  LABEL="CCS: diagnosis 12"

  DXCCS13                    LENGTH=4
  LABEL="CCS: diagnosis 13"

  DXCCS14                    LENGTH=4
  LABEL="CCS: diagnosis 14"

  DXCCS15                    LENGTH=4
  LABEL="CCS: diagnosis 15"

  ECODE1                     LENGTH=$5
  LABEL="E code 1"

  ECODE2                     LENGTH=$5
  LABEL="E code 2"

  ECODE3                     LENGTH=$5
  LABEL="E code 3"

  ECODE4                     LENGTH=$5
  LABEL="E code 4"

  E_CCS1                     LENGTH=3
  LABEL="CCS: E Code 1"

  E_CCS2                     LENGTH=3
  LABEL="CCS: E Code 2"

  E_CCS3                     LENGTH=3
  LABEL="CCS: E Code 3"

  E_CCS4                     LENGTH=3
  LABEL="CCS: E Code 4"

  ELECTIVE                   LENGTH=3
  LABEL="Elective versus non-elective admission"

  FEMALE                     LENGTH=3
  LABEL="Indicator of sex"

  HOSPBRTH                   LENGTH=3
  LABEL="Birth diagnosis, in this hospital"

  HOSPST                     LENGTH=$2
  LABEL="Hospital state postal code"

  KID_STRATUM                LENGTH=3
  LABEL="Hospital stratum used for weights"

  LOS                        LENGTH=4
  LABEL="Length of stay (cleaned)"

  LOS_X                      LENGTH=4
  LABEL="Length of stay (as received from source)"

  MDC                        LENGTH=3
  LABEL="MDC in effect on discharge date"

  MDC18                      LENGTH=3
  LABEL="MDC, version 18"

  MDNUM1_R                   LENGTH=5
  LABEL="Physician 1 number (re-identified)"

  MDNUM2_R                   LENGTH=5
  LABEL="Physician 2 number (re-identified)"

  NDX                        LENGTH=3
  LABEL="Number of diagnoses on this record"

  NECODE                     LENGTH=3
  LABEL="Number of E codes on this record"

  NEOMAT                     LENGTH=3
  LABEL="Neonatal and/or maternal DX and/or PR"

  NPR                        LENGTH=3
  LABEL="Number of procedures on this record"

  PAY1                       LENGTH=3
  LABEL="Primary expected payer (uniform)"

  PAY1_X                     LENGTH=$10
  LABEL="Primary expected payer (as received from source)"

  PAY2                       LENGTH=3
  LABEL="Secondary expected payer (uniform)"

  PAY2_X                     LENGTH=$10
  LABEL="Secondary expected payer (as received from source)"

  PL_UR_CAT4                 LENGTH=3
  LABEL="Patient Location: Urban-Rural 4 Categories"

  PR1                        LENGTH=$4
  LABEL="Principal procedure"

  PR2                        LENGTH=$4
  LABEL="Procedure 2"

  PR3                        LENGTH=$4
  LABEL="Procedure 3"

  PR4                        LENGTH=$4
  LABEL="Procedure 4"

  PR5                        LENGTH=$4
  LABEL="Procedure 5"

  PR6                        LENGTH=$4
  LABEL="Procedure 6"

  PR7                        LENGTH=$4
  LABEL="Procedure 7"

  PR8                        LENGTH=$4
  LABEL="Procedure 8"

  PR9                        LENGTH=$4
  LABEL="Procedure 9"

  PR10                       LENGTH=$4
  LABEL="Procedure 10"

  PR11                       LENGTH=$4
  LABEL="Procedure 11"

  PR12                       LENGTH=$4
  LABEL="Procedure 12"

  PR13                       LENGTH=$4
  LABEL="Procedure 13"

  PR14                       LENGTH=$4
  LABEL="Procedure 14"

  PR15                       LENGTH=$4
  LABEL="Procedure 15"

  PRCCS1                     LENGTH=3
  LABEL="CCS: principal procedure"

  PRCCS2                     LENGTH=3
  LABEL="CCS: procedure 2"

  PRCCS3                     LENGTH=3
  LABEL="CCS: procedure 3"

  PRCCS4                     LENGTH=3
  LABEL="CCS: procedure 4"

  PRCCS5                     LENGTH=3
  LABEL="CCS: procedure 5"

  PRCCS6                     LENGTH=3
  LABEL="CCS: procedure 6"

  PRCCS7                     LENGTH=3
  LABEL="CCS: procedure 7"

  PRCCS8                     LENGTH=3
  LABEL="CCS: procedure 8"

  PRCCS9                     LENGTH=3
  LABEL="CCS: procedure 9"

  PRCCS10                    LENGTH=3
  LABEL="CCS: procedure 10"

  PRCCS11                    LENGTH=3
  LABEL="CCS: procedure 11"

  PRCCS12                    LENGTH=3
  LABEL="CCS: procedure 12"

  PRCCS13                    LENGTH=3
  LABEL="CCS: procedure 13"

  PRCCS14                    LENGTH=3
  LABEL="CCS: procedure 14"

  PRCCS15                    LENGTH=3
  LABEL="CCS: procedure 15"

  PRDAY1                     LENGTH=4
  LABEL="Number of days from admission to PR1"

  PRDAY2                     LENGTH=4
  LABEL="Number of days from admission to PR2"

  PRDAY3                     LENGTH=4
  LABEL="Number of days from admission to PR3"

  PRDAY4                     LENGTH=4
  LABEL="Number of days from admission to PR4"

  PRDAY5                     LENGTH=4
  LABEL="Number of days from admission to PR5"

  PRDAY6                     LENGTH=4
  LABEL="Number of days from admission to PR6"

  PRDAY7                     LENGTH=4
  LABEL="Number of days from admission to PR7"

  PRDAY8                     LENGTH=4
  LABEL="Number of days from admission to PR8"

  PRDAY9                     LENGTH=4
  LABEL="Number of days from admission to PR9"

  PRDAY10                    LENGTH=4
  LABEL="Number of days from admission to PR10"

  PRDAY11                    LENGTH=4
  LABEL="Number of days from admission to PR11"

  PRDAY12                    LENGTH=4
  LABEL="Number of days from admission to PR12"

  PRDAY13                    LENGTH=4
  LABEL="Number of days from admission to PR13"

  PRDAY14                    LENGTH=4
  LABEL="Number of days from admission to PR14"

  PRDAY15                    LENGTH=4
  LABEL="Number of days from admission to PR15"

  RACE                       LENGTH=3
  LABEL="Race (uniform)"

  TOTCHG                     LENGTH=6
  LABEL="Total charges (cleaned)"

  TOTCHG_X                   LENGTH=7
  LABEL="Total charges (as received from source)"

  UNCBRTH                    LENGTH=3
  LABEL="Normal uncomplicated birth in hospital"

  YEAR                       LENGTH=3
  LABEL="Calendar year"

  ZIPInc_Qrtl                LENGTH=3
  LABEL="Median household income quartile for patient's ZIP Code"
  ;


*** Input the variables from the ASCII file ***;
INPUT 
      @1      HOSPID                   5.
      @6      RECNUM                   N8PF.
      @14     AGE                      N3PF.
      @17     AGEDAY                   N3PF.
      @20     AGEMONTH                 N3PF.
      @23     AMONTH                   N2PF.
      @25     ASOURCE                  N2PF.
      @27     ASOURCEUB92              $CHAR1.
      @28     ASOURCE_X                $CHAR8.
      @36     ATYPE                    N2PF.
      @38     AWEEKEND                 N2PF.
      @40     BWT                      N4PF.
      @44     DIED                     N2PF.
      @46     DISCWT                   N11P7F.
      @57     DISPUB92                 N2PF.
      @59     DISPUNIFORM              N2PF.
      @61     DQTR                     N2PF.
      @63     DRG                      N3PF.
      @66     DRG18                    N3PF.
      @69     DRGVER                   N2PF.
      @71     DSHOSPID                 $CHAR13.
      @84     DX1                      $CHAR5.
      @89     DX2                      $CHAR5.
      @94     DX3                      $CHAR5.
      @99     DX4                      $CHAR5.
      @104    DX5                      $CHAR5.
      @109    DX6                      $CHAR5.
      @114    DX7                      $CHAR5.
      @119    DX8                      $CHAR5.
      @124    DX9                      $CHAR5.
      @129    DX10                     $CHAR5.
      @134    DX11                     $CHAR5.
      @139    DX12                     $CHAR5.
      @144    DX13                     $CHAR5.
      @149    DX14                     $CHAR5.
      @154    DX15                     $CHAR5.
      @159    DXCCS1                   N4PF.
      @163    DXCCS2                   N4PF.
      @167    DXCCS3                   N4PF.
      @171    DXCCS4                   N4PF.
      @175    DXCCS5                   N4PF.
      @179    DXCCS6                   N4PF.
      @183    DXCCS7                   N4PF.
      @187    DXCCS8                   N4PF.
      @191    DXCCS9                   N4PF.
      @195    DXCCS10                  N4PF.
      @199    DXCCS11                  N4PF.
      @203    DXCCS12                  N4PF.
      @207    DXCCS13                  N4PF.
      @211    DXCCS14                  N4PF.
      @215    DXCCS15                  N4PF.
      @219    ECODE1                   $CHAR5.
      @224    ECODE2                   $CHAR5.
      @229    ECODE3                   $CHAR5.
      @234    ECODE4                   $CHAR5.
      @239    E_CCS1                   N4PF.
      @243    E_CCS2                   N4PF.
      @247    E_CCS3                   N4PF.
      @251    E_CCS4                   N4PF.
      @255    ELECTIVE                 N2PF.
      @257    FEMALE                   N2PF.
      @259    HOSPBRTH                 N2PF.
      @261    HOSPST                   $CHAR2.
      @263    KID_STRATUM              N4PF.
      @267    LOS                      N5PF.
      @272    LOS_X                    N6PF.
      @278    MDC                      N2PF.
      @280    MDC18                    N2PF.
      @282    MDNUM1_R                 N5PF.
      @287    MDNUM2_R                 N5PF.
      @292    NDX                      N2PF.
      @294    NECODE                   N3PF.
      @297    NEOMAT                   N2PF.
      @299    NPR                      N2PF.
      @301    PAY1                     N2PF.
      @303    PAY1_X                   $CHAR10.
      @313    PAY2                     N2PF.
      @315    PAY2_X                   $CHAR10.
      @325    PL_UR_CAT4               N2PF.
      @327    PR1                      $CHAR4.
      @331    PR2                      $CHAR4.
      @335    PR3                      $CHAR4.
      @339    PR4                      $CHAR4.
      @343    PR5                      $CHAR4.
      @347    PR6                      $CHAR4.
      @351    PR7                      $CHAR4.
      @355    PR8                      $CHAR4.
      @359    PR9                      $CHAR4.
      @363    PR10                     $CHAR4.
      @367    PR11                     $CHAR4.
      @371    PR12                     $CHAR4.
      @375    PR13                     $CHAR4.
      @379    PR14                     $CHAR4.
      @383    PR15                     $CHAR4.
      @387    PRCCS1                   N3PF.
      @390    PRCCS2                   N3PF.
      @393    PRCCS3                   N3PF.
      @396    PRCCS4                   N3PF.
      @399    PRCCS5                   N3PF.
      @402    PRCCS6                   N3PF.
      @405    PRCCS7                   N3PF.
      @408    PRCCS8                   N3PF.
      @411    PRCCS9                   N3PF.
      @414    PRCCS10                  N3PF.
      @417    PRCCS11                  N3PF.
      @420    PRCCS12                  N3PF.
      @423    PRCCS13                  N3PF.
      @426    PRCCS14                  N3PF.
      @429    PRCCS15                  N3PF.
      @432    PRDAY1                   N3PF.
      @435    PRDAY2                   N3PF.
      @438    PRDAY3                   N3PF.
      @441    PRDAY4                   N3PF.
      @444    PRDAY5                   N3PF.
      @447    PRDAY6                   N3PF.
      @450    PRDAY7                   N3PF.
      @453    PRDAY8                   N3PF.
      @456    PRDAY9                   N3PF.
      @459    PRDAY10                  N3PF.
      @462    PRDAY11                  N3PF.
      @465    PRDAY12                  N3PF.
      @468    PRDAY13                  N3PF.
      @471    PRDAY14                  N3PF.
      @474    PRDAY15                  N3PF.
      @477    RACE                     N2PF.
      @479    TOTCHG                   N10PF.
      @489    TOTCHG_X                 N15P2F.
      @504    UNCBRTH                  N2PF.
      @506    YEAR                     N4PF.
      @510    ZIPInc_Qrtl              N2PF.
      ;


RUN;
